function ampl_factor = g(gdata,theta,f)
% Usage:
% ampl_factor = G(gdata,theta,f);
%
% Returns amplification factor for the sound pressure level for any given
% frequency (f) and angle (theta) of the loudspeaker defined in 'gdata'.
% 'gdata' must be of size 73x667, and consist of angle-data in rows, and
% frequency-data in columns.
%
% 'ampl_factor'  - output factor (scalar, and never >1)
% 'theta'        - angle (-pi to +pi)
% 'f'            - frequency [Hz] (<20000 Hz)
%

samplefrequency = 48000;    % Samplefrequency used to create the speaker-measurements
cutofffrequency = 20000;    % Maximum frequency in FFT plots
frequencystep = 2.5;          % 5 Hz frequency step between measurements
selected_bin_no = round(667 * f / cutofffrequency);
angle=abs(360 * theta / (2 * pi)); % Calculate absolute angle in degrees

%if abs(theta)>pi/2          % No radiation >90 degrees
%    ampl_factor=0;
%else
    ampl_factor = (1 - mod(angle,frequencystep) / frequencystep) * gdata(1 + floor(angle / frequencystep),selected_bin_no) + (mod(angle,frequencystep) / frequencystep) * gdata(1 + ceil(angle / frequencystep),selected_bin_no); % Linear interpolation between measured angles
%end