% Programm loads 24 driving signals for wfs and gives them back with
% randomized phase in their high frequency content.

clear all;
close all;
clc;

load 'Output_signals.mat';  
fs = 48000;
noise_amount = 1;    % Amount of noise added to the high frequency content in multiples of pi.
cutoff_frq = 1000;   % Frequency that separates low and high frequency content.

for m = 1:24   % Loop for calculating phase shifting for each loudspeaker in the array.
    music = Cwav_resampled(m,:);   % Loads one driving signal a time.
	window = hanning(256);
	
	music_rand = zeros(floor(length(music)/128),256);
	
	[B,A] = butter(6,(2*cutoff_frq)/fs);   % Lowpass filter butterworth 6th order.
	music_long_low = filter(B,A,music);    % Low frequency content of the signal will be unchanged.
	
	[B,A] = butter(6,(2*cutoff_frq)/fs,'high');   % Highpass filter
	music_long_high = filter(B,A,music);          % High frequency content of the signal
	    
	k = 0;
	for i = 1:128:floor(length(music)/128)*128-256   % Goes through each signal in 128 sample steps.
        k = k + 1;
        
        music_short_high = music_long_high(i:i+255)';   % Cuts out 256 samples.
        
        music_high_phase = angle(fft(music_short_high));   % Separates into phase
		music_high_amp = abs(fft(music_short_high));       % and amplitude.
				
		music_high_phase_rand = zeros(length(music_high_phase),1);   
		noise = (rand(length(music_high_phase)/2,1)-.5) * pi * noise_amount;   % Creates a vector of 126 samples with phase noise between -pi/2 and pi/2.
		
		music_high_phase_rand(1:length(music_high_phase)/2) = noise + music_high_phase(1:length(music_high_phase)/2);   % Adds phase noise to the first half of the phase of the signal.
		music_high_phase_rand(length(music_high_phase)/2+1:length(music_high_phase)) = -noise(length(noise):-1:1) + music_high_phase(length(music_high_phase)/2+1 : length(music_high_phase));   %does the same mirrored for second half of the phase
		
		j = sqrt(-1);   %defines complex j
		music_high_rand_fft = music_high_amp .* exp(j .* music_high_phase_rand);   % Recalculates the complex signal with changed phase.
		music_high_rand = real(ifft(music_high_rand_fft));   % Inverse fft and taking the real part of it.
		
		[B,A] = butter(6,(2*cutoff_frq)/fs,'high');   % Highpass filter removes the phase noise in the range of low frequency content.
		music_high_rand_high = filter(B,A,music_high_rand);
		
		music_rand(k,:) = music_high_rand_high' .* window';   %applies hanning window to resulting signal
    end
	
	music_out_high = zeros(1,length(music)+256);  
	music_out = zeros(1,length(music)+256);
	
	for i = 1:size(music_rand,1)   % Combines all windowed parts to the original high frequency content signal with overlap of 128 samples.
        music_out_high(i*128-127:i*128+128) = music_rand(i,:) + music_out_high(i*128-127:i*128+128);   
	end
	
	music_out = music_out_high + [music_long_low zeros(1,256)];   % Sums up low and high frequency content.
	
    %[B,A] = butter(6,(2*1000)/fs);   % Only if resulting low frequency content is wanted.
	%music_out = filter(B,A,music_out);
    
 	Cwav_resampled(m,:) = music_out(1:length(music));   % Saves each changed driving signal.
end

save 'Output_signals_random_phase.mat' Cwav_resampled;
