% All definitions for the simulation are made here. Resulting
% variables are calculated. For instance the maximum needed angle 
% from any loudspeaker to any area point or the position of the 
% loudspeakers or the listening area. 
% Length units are in mm.

load ir27;               % Contains the measured inverted impulse responses for one loudspeaker in 2.5 degree steps.

%load ir_dipole180;      % It is also possible to use different premade loudspeaker characteristics.
%load ir_ideal;          % For instance dipole or monopole characteristics.
%ir = ir_ideal;

simulation_description = 'sin5000Hz'; % Describes the current simulation, and will be contained in the output filename.
simulation_type = 1;       % 1 = snapshot of sound pressure in room, saved to tif-file.
                           % 2 = sampling of sound in single point in the point (sampling_point_x,sampling_point_z), saved to wav-file.
no_speakers_array = 24;
interpolation = 1;         % 0 = Nearest neighbor, 1 = bilinear interpolation (angle and time)
snapshot_time = 250;       % Snapshot made at 250 samples after the first emitted sample.
snapshot_resolution = 10;  % Stepsize between simulation points in the simulation area.
delta_x = 155;             % Speaker diameter 155 mm
dist_area_array = 0;       % Distance from simulation area to loudspeaker array = 0 m, must not be smaller than zero.
size_area = 5000;          % Simulation area is quadratic with sides of 5 m.
listarea_top_left_x = -750;     %
listarea_top_left_z = 500;      % Centered square listening area of 1.5x1.5 m
listarea_bottom_right_x = 750;  %
listarea_bottom_right_z = 2000; %
sampling_point_x = 0;           % Sample x-coordinate - centre of listening area
sampling_point_z = 1250;        % Sample z-coordinate - centre of listening area
sampling_time_start = 1;        % Time to start sampling (unit in samples)
sampling_time_end = 4000;       % Time to end sampling (unit in samples)

order_reflections = 0;          % 0 = no reflections, 1,2 = 1st or 2nd order of reflections from side walls (BIG PERFORMANCE HIT)
reflection_koefficient = 0.5;   % Reflection koefficient in the range [0 ; 1]

speed_of_sound_mps = 343;       % 343 m/s
sample_frequency = 48000;
distance_threshold = 72;        % Size of white circles on loudspeaker positions.
measurement_step_degrees = 2.5; % Angle steps in the impulse response measurement of the loudspeakers in degree.

area_start_x = -size_area / 2;
area_end_x = size_area / 2;
area_start_z = dist_area_array;
area_end_z = dist_area_array + size_area;
size_array = no_speakers_array * delta_x - delta_x;

impulse_response_length = size(ir,2);
number_angles = 90 / measurement_step_degrees + 1; 

speed_of_sound = speed_of_sound_mps * 1000 / sample_frequency; % Result in mm/sample.

speaker_reflection_order = zeros(1,no_speakers_array);
no_speakers = no_speakers_array + order_reflections * 2 * no_speakers_array;

x_speaker_position_base = [0 : delta_x : size_array] - size_array/2; % Calculate individual speaker x-positions with the array centered.
x_speaker_position=x_speaker_position_base;

for i = 1 : order_reflections
    x_speaker_position = [(x_speaker_position_base-size_area*i) x_speaker_position (x_speaker_position_base+size_area*i)];
    speaker_reflection_order = [ones(1,no_speakers_array)*i speaker_reflection_order ones(1,no_speakers_array)*i];
end

if dist_area_array == 0
    maximum_emitting_angle = ones(1,no_speakers) * 90; % If the the simulation area abuts the array, the maximum emitting angle for the loudspeakers will be 90 degree.
else
    maximum_emitting_angle = (180/pi) * atan((size_area/2 + abs(x_speaker_position)) / dist_area_array); % Else the maximum angle between any loudspeaker and any area point will be smaller.
    maximum_emitting_angle = ceil(maximum_emitting_angle / measurement_step_degrees) * measurement_step_degrees; % Round off to next measured angle.
end
