% The program needs the driving functions for each loudspeaker calculated
% in dfprogram.m and the same impulse responses of the loudspeaker like used in the
% simulation and in the calculation of the driving functions. The input
% signals are weighted with a truncation window and convoluted with the
% impulse responses of the loudspeaker for all needed angels. The results
% are saved in speaker_output.mat.
% It is also possible to calculate this data for reflections up to second
% order.

clear all;
close all;
clc;

tic                      % Start measurement of time.

simulation_definitions;  % All definitions are contained in simulation_definitions.m

load 'Output_signals.mat';                % Contains the driving functions for each loudspeaker.
Cwav_resampled = stereo_signal_resampled; % Only needed if the input in drivingfunction.m was a stereo file.

window = createwindow(no_speakers_array); % Gives back the used truncation window.

for i=1:no_speakers_array                 % Applies truncation window.
    speakersignal(i,:) = Cwav_resampled(i,:) * window(i);
end

length_signal = size(Cwav_resampled,2);   % Length of all driving functions.

speaker_output_base = zeros(no_speakers_array, number_angles, impulse_response_length + length_signal - 1); 
speaker_output = zeros(no_speakers, number_angles, impulse_response_length + length_signal - 1);

%for i=1:no_speakers_array,
%    speakersignal(i,:) = inputsignal';   % Same output from all speakers, just for test purposes
%end

for i = 1 : no_speakers_array,   % Calculates the convolution between loudspeaker impulse response
    for j = 1 : number_angles    % and driving function for all loudspeakers and all needed angels.
        if j > maximum_emitting_angle/measurement_step_degrees 
            speaker_output_base(i,j,:) = zeros(1,impulse_response_length + length_signal - 1);
        else
            speaker_output_base(i,j,:) = conv(ir(j,:),speakersignal(i,:));    
        end
    end
end

switch order_reflections         % Clones the speaker output if reflections shall be simulated.
  case 0,
    speaker_output = speaker_output_base;
  case 1,
    speaker_output = [speaker_output_base(no_speakers_array:-1:1,:,:) ; speaker_output_base ; speaker_output_base(no_speakers_array:-1:1,:,:)];
  case 2,
    speaker_output = [speaker_output_base ; speaker_output_base(no_speakers_array:-1:1,:,:) ; speaker_output_base ; speaker_output_base(no_speakers_array:-1:1,:,:) ; speaker_output_base];
  otherwise,
    speaker_output = zeros(no_speakers, number_angles, impulse_response_length + length_signal - 1);
    disp('Error: Too high order');
end

for i = 1 : no_speakers,         % Weights the speaker outputs with the reflection koefficients.
    speaker_output(i,:,:) = speaker_output(i,:,:) .* (reflection_koefficient .^ speaker_reflection_order(i));
end

save 'speaker_output' speaker_output;   % Saves speaker-output for simulation.

toc  % End measurement of time.